blockquote.pdf

## Metadata

Title | blockquote.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\blockquote.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403055145+01'00'
PDF Metadata: modDate | D:20230403055145+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h4 :: Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 491.8059997558594
y1 |  | 113.30770111083984
y0 |  | 73.70773315429688
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 500.2680358886719
y1 |  | 168.74771118164062
y0 |  | 129.14773559570312
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 510.4613342285156
y1 |  | 219.669189453125
y0 |  | 185.22921752929688
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 523.0800170898438
y1 |  | 288.7777404785156
y0 |  | 235.37771606445312
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 444.9188537597656
y1 |  | 334.85186767578125
y0 |  | 300.5318908691406
x0 |  | 77.18399810791016

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 518.6640625
y1 |  | 416.47772216796875
y0 |  | 349.2577209472656
x0 |  | 72.02400207519531

Et quis odio hic neque consequuntur sed similique quia. Ut similique dolorum vel odio provident ut quae sapiente aut quia quia hic quas voluptatem. Ad rerum magni sed consequatur unde et galisum similique.

At quaerat tempora qui nihil quaerat et quos inventore ea delectus perspiciatis. Qui optio labore quo sunt neque et voluptates aspernatur ea consequatur quia et sapiente odit sed nesciunt repudiandae ut cumque nostrum.

Et velit amet ut quos doloremque ut eligendi dolores ex doloremque voluptatem rem cumque totam est internos nostrum.

Est autem optio id voluptatem itaque et maxime nihil ut impedit voluptate ut consequatur vero a laudantium reiciendis. Et officiis vero aut numquam doloremque et quisquam exercitationem. Qui consequatur rerum qui molestiae illo aut quisquam rerum et labore totam quo beatae dolores.

#### Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

Sed impedit consequuntur ea omnis voluptatum non provident culpa et pariatur voluptatibus et tempore rerum qui officia consequatur. Qui accusamus porro est praesentium repudiandae rem ducimus veritatis qui vitae repellendus sed quos voluptatem et natus facilis ex eaque dolore. In beatae ullam est dicta fuga aut veniam illo quo facilis galisum et unde esse. Aut dolores earum ut labore cumque cum sint dicta ut voluptatem quae sed culpa iure!

Et quis odio hic neque consequuntur sed similique quia. Ut similique dolorum vel odio provident ut quae sapiente aut quia quia hic quas voluptatem. Ad rerum magni sed consequatur unde et galisum similique.

At quaerat tempora qui nihil quaerat et quos inventore ea delectus perspiciatis. Qui optio labore quo sunt neque et voluptates aspernatur ea consequatur quia et sapiente odit sed nesciunt repudiandae ut cumque nostrum.

Et velit amet ut quos doloremque ut eligendi dolores ex doloremque voluptatem rem cumque totam est internos nostrum.

Est autem optio id voluptatem itaque et maxime nihil ut impedit voluptate ut consequatur vero a laudantium reiciendis. Et officiis vero aut numquam doloremque et quisquam exercitationem. Qui consequatur rerum qui molestiae illo aut quisquam rerum et labore totam quo beatae dolores.

#### Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

Sed impedit consequuntur ea omnis voluptatum non provident culpa et pariatur voluptatibus et tempore rerum qui officia consequatur. Qui accusamus porro est praesentium repudiandae rem ducimus veritatis qui vitae repellendus sed quos voluptatem et natus facilis ex eaque dolore. In beatae ullam est dicta fuga aut veniam illo quo facilis galisum et unde esse. Aut dolores earum ut labore cumque cum sint dicta ut voluptatem quae sed culpa iure!

Parent File Contents